pub struct SentryBuilder { /* private fields */ }Available on crate feature
actix only.Expand description
A helper construct that can be used to reconfigure and build the middleware.
Implementations
Sourceimpl SentryBuilder
impl SentryBuilder
Sourcepub fn start_transaction(self, start_transaction: bool) -> SentryBuilder
pub fn start_transaction(self, start_transaction: bool) -> SentryBuilder
Tells the middleware to start a new performance monitoring transaction for each request.
Sourcepub fn with_hub(self, hub: Arc<Hub>) -> SentryBuilder
pub fn with_hub(self, hub: Arc<Hub>) -> SentryBuilder
Reconfigures the middleware so that it uses a specific hub instead of the default one.
Sourcepub fn with_default_hub(self) -> SentryBuilder
pub fn with_default_hub(self) -> SentryBuilder
Reconfigures the middleware so that it uses a specific hub instead of the default one.
Sourcepub fn emit_header(self, val: bool) -> SentryBuilder
pub fn emit_header(self, val: bool) -> SentryBuilder
If configured the sentry id is attached to a X-Sentry-Event header.
Sourcepub fn capture_server_errors(self, val: bool) -> SentryBuilder
pub fn capture_server_errors(self, val: bool) -> SentryBuilder
Enables or disables error reporting.
The default is to report all errors.