Struct sentry::Envelope [−]
pub struct Envelope { /* fields omitted */ }Expand description
A Sentry Envelope.
An Envelope is the data format that Sentry uses for Ingestion. It can contain multiple Items, some of which are related, such as Events, and Event Attachments. Other Items, such as Sessions are independent.
See the documentation on Envelopes for more details.
Implementations
impl Envelope
impl Envelopepub fn add_item<I>(&mut self, item: I) where
I: Into<EnvelopeItem>,
pub fn add_item<I>(&mut self, item: I) where
I: Into<EnvelopeItem>, Add a new Envelope Item.
pub fn items(&self) -> EnvelopeItemIter<'_>ⓘNotable traits for EnvelopeItemIter<'s>
impl<'s> Iterator for EnvelopeItemIter<'s> type Item = &'s EnvelopeItem;
pub fn items(&self) -> EnvelopeItemIter<'_>ⓘNotable traits for EnvelopeItemIter<'s>
impl<'s> Iterator for EnvelopeItemIter<'s> type Item = &'s EnvelopeItem;Create an Iterator over all the EnvelopeItems.